Method: String#titleize

Defined in:
lib/wedge/utilis/titleize.rb

#titleize(opts = {}) ⇒ Object Also known as: titlecase

Capitalizes most words to create a nicer looking title string.

The list of “small words” which are not capped comes from the New York Times Manual of Style, plus ‘vs’ and ‘v’.

titleize is also aliased as titlecase.

"notes on a scandal" # => "Notes on a Scandal"
"the good german"    # => "The Good German"


85
86
87
88
89
90
91
# File 'lib/wedge/utilis/titleize.rb', line 85

def titleize(opts={})
  # if defined? ActiveSupport
  #   ActiveSupport::Inflector.titleize(self, opts)
  # else
    Titleize.titleize(self)
  # end
end